@@ -128,10 +128,6 @@ namespace Magick
     void operator()( Image &image_ ) const;
 
   private:
-    // Copy constructor and assignment are not supported
-    annotateImage(const annotateImage&);
-    annotateImage& operator=(const annotateImage&);
-
     const std::string   _text;
     const Geometry      _geometry;
     const GravityType   _gravity;
@@ -1927,7 +1923,7 @@ namespace Magick
   // container's begin() method and last_ via the container's end()
   // method in order to specify the entire container.
   template <class InputIterator>
-  void linkImages( InputIterator first_,
+  bool linkImages( InputIterator first_,
        InputIterator last_ ) {
 
     MagickCore::Image* previous = 0;
@@ -1950,6 +1946,7 @@ namespace Magick
 
       previous = current;
     }
+    return(scene > 0 ? true : false);
   }
 
   // Remove links added by linkImages. This should be called after the
@@ -2001,8 +1998,9 @@ namespace Magick
   template <class InputIterator>
   void animateImages( InputIterator first_,
           InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::AnimateImages( first_->imageInfo(), first_->image() );
     MagickCore::GetImageException( first_->image(), exceptionInfo );
     unlinkImages( first_, last_ );
@@ -2016,8 +2014,9 @@ namespace Magick
          InputIterator first_,
          InputIterator last_,
          bool stack_ = false) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = MagickCore::AppendImages( first_->image(),
                    (MagickBooleanType) stack_,
                    exceptionInfo ); 
@@ -2026,6 +2025,42 @@ namespace Magick
     ThrowPPException(appendedImage_->quiet());
   }
 
+  // Adds the names of the artifacts of the image to the container.
+  template <class Container>
+  void artifactNames(Container *names_,const Image* image_)
+  {
+    char*
+      name;
+
+    names_->clear();
+
+    MagickCore::ResetImageArtifactIterator(image_->constImage());
+    name=MagickCore::GetNextImageArtifact(image_->constImage());
+    while (name != (char *) NULL)
+    {
+      names_->push_back(std::string(name));
+      name=MagickCore::GetNextImageArtifact(image_->constImage());
+    }
+  }
+
+  // Adds the names of the attributes of the image to the container.
+  template <class Container>
+  void attributeNames(Container *names_,const Image* image_)
+  {
+    char*
+      name;
+
+    names_->clear();
+
+    MagickCore::ResetImagePropertyIterator(image_->constImage());
+    name=MagickCore::GetNextImageProperty(image_->constImage());
+    while (name != (char *) NULL)
+    {
+      names_->push_back(std::string(name));
+      name=MagickCore::GetNextImageProperty(image_->constImage());
+    }
+  }
+
   // Average a set of images.
   // All the input images must be the same size in pixels.
   template <class InputIterator>
@@ -2050,10 +2085,10 @@ namespace Magick
   void coalesceImages( Container *coalescedImages_,
                        InputIterator first_,
                        InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
 
-    // Build image list
-    linkImages( first_, last_ );
     MagickCore::Image* images = MagickCore::CoalesceImages( first_->image(),
                                                           exceptionInfo);
     // Unlink image list
@@ -2219,8 +2254,9 @@ namespace Magick
                       InputIterator first_,
                       InputIterator last_,
                       const ChannelType channel_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = CombineImages( first_->image(), channel_, exceptionInfo );
     unlinkImages( first_, last_ );
     combinedImage_->replaceImage( image );
@@ -2245,10 +2281,11 @@ namespace Magick
   void deconstructImages( Container *deconstructedImages_,
                           InputIterator first_,
                           InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
+
     GetPPException;
 
-    // Build image list
-    linkImages( first_, last_ );
     MagickCore::Image* images = DeconstructImages( first_->image(),
                                                    exceptionInfo);
     // Unlink image list
@@ -2270,8 +2307,9 @@ namespace Magick
   template <class InputIterator>
   void displayImages( InputIterator first_,
           InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::DisplayImages( first_->imageInfo(), first_->image() );
     MagickCore::GetImageException( first_->image(), exceptionInfo );
     unlinkImages( first_, last_ );
@@ -2287,8 +2325,9 @@ namespace Magick
                        InputIterator first_,
                        InputIterator last_,
                        const MagickEvaluateOperator operator_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = EvaluateImages( first_->image(), operator_, exceptionInfo );
     unlinkImages( first_, last_ );
     evaluatedImage_->replaceImage( image );
@@ -2301,8 +2340,9 @@ namespace Magick
   void flattenImages( Image *flattendImage_,
           InputIterator first_,
           InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = MagickCore::MergeImageLayers( first_->image(),
       FlattenLayer,exceptionInfo );
     unlinkImages( first_, last_ );
@@ -2358,8 +2398,9 @@ namespace Magick
     MagickCore::Image
       *image;
 
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages(first_,last_);
     image=FxImageChannel(first_->constImage(),DefaultChannels,
       expression.c_str(),exceptionInfo);
     unlinkImages(first_,last_);
@@ -2378,11 +2419,12 @@ namespace Magick
       bool dither_ = false,
       bool measureError_ = false ) {
 
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
     MagickCore::QuantizeInfo quantizeInfo;
     MagickCore::GetQuantizeInfo( &quantizeInfo );
     quantizeInfo.dither = dither_ ? MagickCore::MagickTrue : MagickCore::MagickFalse;
-    linkImages( first_, last_ );
     MagickCore::RemapImages( &quantizeInfo, first_->image(),
         (mapImage_.isValid() ? mapImage_.constImage() : (const MagickCore::Image*) NULL));
     MagickCore::GetImageException( first_->image(), exceptionInfo );
@@ -2429,8 +2471,9 @@ namespace Magick
                          InputIterator first_,
                          InputIterator last_,
                          const ImageLayerMethod method_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = MergeImageLayers( first_->image(), method_, exceptionInfo );
     unlinkImages( first_, last_ );
     mergedImage_->replaceImage( image );
@@ -2448,6 +2491,9 @@ namespace Magick
     MagickCore::MontageInfo
       *montageInfo;
 
+    if (linkImages(first_,last_) == false)
+      return;
+
     montageInfo=static_cast<MagickCore::MontageInfo*>(
       MagickCore::AcquireMagickMemory(sizeof(MagickCore::MontageInfo)));
 
@@ -2458,9 +2504,6 @@ namespace Magick
     if (options_.label().length() != 0)
       first_->label(options_.label());
 
-    // Create linked image list
-    linkImages(first_,last_);
-
     // Do montage
     GetPPException;
     images=MagickCore::MontageImages(first_->image(),montageInfo,
@@ -2493,10 +2536,10 @@ namespace Magick
         InputIterator first_,
         InputIterator last_,
         size_t frames_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
 
-    // Build image list
-    linkImages( first_, last_ );
     MagickCore::Image* images = MagickCore::MorphImages( first_->image(), frames_,
                    exceptionInfo);
     // Unlink image list
@@ -2517,8 +2560,9 @@ namespace Magick
   void mosaicImages( Image *mosaicImage_,
          InputIterator first_,
          InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages( first_, last_ );
     MagickCore::Image* image = MagickCore::MergeImageLayers( first_->image(),
        MosaicLayer,exceptionInfo ); 
     unlinkImages( first_, last_ );
@@ -2534,9 +2578,9 @@ namespace Magick
   void optimizeImageLayers( Container *optimizedImages_,
                             InputIterator first_,
                             InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-
-    linkImages( first_, last_ );
     MagickCore::Image* images = OptimizeImageLayers( first_->image(), exceptionInfo );
 
     unlinkImages( first_, last_ );
@@ -2555,9 +2599,9 @@ namespace Magick
   void optimizePlusImageLayers( Container *optimizedImages_,
                                 InputIterator first_,
                                 InputIterator last_ ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-
-    linkImages( first_, last_ );
     MagickCore::Image* images = OptimizePlusImageLayers( first_->image(), exceptionInfo );
 
     unlinkImages( first_, last_ );
@@ -2575,9 +2619,9 @@ namespace Magick
   template<class InputIterator>
   void optimizeTransparency(InputIterator first_,InputIterator last_)
   {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-
-    linkImages(first_,last_);
     OptimizeImageTransparency(first_->image(),exceptionInfo);
     unlinkImages(first_,last_ );
 
@@ -2608,10 +2652,10 @@ namespace Magick
   void quantizeImages( InputIterator first_,
            InputIterator last_,
            bool measureError_ = false ) {
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
 
-    linkImages( first_, last_ );
-
     MagickCore::QuantizeImages( first_->quantizeInfo(),
              first_->image() );
     MagickCore::GetImageException( first_->image(), exceptionInfo );
@@ -2711,8 +2755,9 @@ namespace Magick
     MagickCore::Image
       *newImage;
 
+    if (linkImages(first_,last_) == false)
+      return;
     GetPPException;
-    linkImages(first_,last_);
     newImage=MagickCore::SmushImages(first_->constImage(),
       (MagickBooleanType) stack_,offset_,exceptionInfo);
     unlinkImages(first_,last_);
@@ -2726,12 +2771,12 @@ namespace Magick
         InputIterator last_,
         const std::string &imageSpec_,
         bool adjoin_ = true ) {
+    if (linkImages(first_,last_) == false)
+      return;
 
     first_->adjoin( adjoin_ );
 
     GetPPException;
-
-    linkImages( first_, last_ );
     ::ssize_t errorStat = MagickCore::WriteImages( first_->constImageInfo(),
                                             first_->image(),
                                             imageSpec_.c_str(),
@@ -2752,11 +2797,11 @@ namespace Magick
         InputIterator last_,
         Blob *blob_,
         bool adjoin_ = true) {
+    if (linkImages(first_,last_) == false)
+      return;
 
     first_->adjoin( adjoin_ );
 
-    linkImages( first_, last_ );
-
     GetPPException;
     size_t length = 2048; // Efficient size for small images
     void* data = MagickCore::ImagesToBlob( first_->imageInfo(),
