@@ -20,7 +20,7 @@
 %                               October 2003                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -589,7 +589,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Image origination information.
   */
-  cin.origination.x_offset=(int) ReadBlobLong(image);
+  cin.origination.x_offset=ReadBlobSignedLong(image);
   offset+=4;
   if ((size_t) cin.origination.x_offset != ~0UL)
     (void) FormatImageProperty(image,"dpx:origination.x_offset","%.20g",
