@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -141,7 +141,8 @@ static size_t GetNumberChannels(const Image *image,const ChannelType channel)
 }
 
 static inline MagickBooleanType ValidateImageMorphology(
-  const Image *restrict image,const Image *restrict reconstruct_image)
+  const Image *magick_restrict image,
+  const Image *magick_restrict reconstruct_image)
 {
   /*
     Does the image match the reconstructed image morphology?
@@ -255,18 +256,18 @@ MagickExport Image *CompareImageChannels(Image *image,
       reconstruct_pixel;
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register IndexPacket
-      *restrict highlight_indexes;
+      *magick_restrict highlight_indexes;
 
     register PixelPacket
-      *restrict r;
+      *magick_restrict r;
 
     register ssize_t
       x;
@@ -339,6 +340,7 @@ MagickExport Image *CompareImageChannels(Image *image,
   reconstruct_view=DestroyCacheView(reconstruct_view);
   image_view=DestroyCacheView(image_view);
   (void) CompositeImage(difference_image,image->compose,highlight_image,0,0);
+  (void) SetImageAlphaChannel(difference_image,DeactivateAlphaChannel);
   highlight_image=DestroyImage(highlight_image);
   if (status == MagickFalse)
     difference_image=DestroyImage(difference_image);
@@ -437,12 +439,12 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
       reconstruct_pixel;
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       i,
@@ -533,12 +535,12 @@ static MagickBooleanType GetFuzzDistortion(const Image *image,
       channel_distortion[CompositeChannels+1];
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       i,
@@ -663,12 +665,12 @@ static MagickBooleanType GetMeanAbsoluteDistortion(const Image *image,
       channel_distortion[CompositeChannels+1];
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       i,
@@ -782,12 +784,12 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
   for (y=0; y < (ssize_t) rows; y++)
   {
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       x;
@@ -915,12 +917,12 @@ static MagickBooleanType GetMeanSquaredDistortion(const Image *image,
       channel_distortion[CompositeChannels+1];
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       i,
@@ -1056,18 +1058,18 @@ static MagickBooleanType GetNormalizedCrossCorrelationDistortion(
     distortion[i]=0.0;
   rows=MagickMax(image->rows,reconstruct_image->rows);
   columns=MagickMax(image->columns,reconstruct_image->columns);
-  area=1.0/((MagickRealType) columns*rows-1);
+  area=1.0/((MagickRealType) columns*rows);
   image_view=AcquireVirtualCacheView(image,exception);
   reconstruct_view=AcquireVirtualCacheView(reconstruct_image,exception);
   for (y=0; y < (ssize_t) rows; y++)
   {
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       x;
@@ -1205,12 +1207,12 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
       channel_distortion[CompositeChannels+1];
 
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       i,
@@ -1318,24 +1320,30 @@ static MagickBooleanType GetPeakSignalToNoiseRatio(const Image *image,
   status=GetMeanSquaredDistortion(image,reconstruct_image,channel,distortion,
     exception);
   if ((channel & RedChannel) != 0)
-    distortion[RedChannel]=20.0*MagickLog10((double) 1.0/sqrt(
-      distortion[RedChannel]));
+    if (fabs(distortion[RedChannel]) >= MagickEpsilon)
+      distortion[RedChannel]=20.0*MagickLog10((double) 1.0/sqrt(
+        distortion[RedChannel]));
   if ((channel & GreenChannel) != 0)
-    distortion[GreenChannel]=20.0*MagickLog10((double) 1.0/sqrt(
-      distortion[GreenChannel]));
+    if (fabs(distortion[GreenChannel]) >= MagickEpsilon)
+      distortion[GreenChannel]=20.0*MagickLog10((double) 1.0/sqrt(
+        distortion[GreenChannel]));
   if ((channel & BlueChannel) != 0)
-    distortion[BlueChannel]=20.0*MagickLog10((double) 1.0/sqrt(
-      distortion[BlueChannel]));
+    if (fabs(distortion[BlueChannel]) >= MagickEpsilon)
+      distortion[BlueChannel]=20.0*MagickLog10((double) 1.0/sqrt(
+        distortion[BlueChannel]));
   if (((channel & OpacityChannel) != 0) &&
       (image->matte != MagickFalse))
-    distortion[OpacityChannel]=20.0*MagickLog10((double) 1.0/sqrt(
-      distortion[OpacityChannel]));
+    if (fabs(distortion[OpacityChannel]) >= MagickEpsilon)
+      distortion[OpacityChannel]=20.0*MagickLog10((double) 1.0/sqrt(
+        distortion[OpacityChannel]));
   if (((channel & IndexChannel) != 0) &&
       (image->colorspace == CMYKColorspace))
-    distortion[BlackChannel]=20.0*MagickLog10((double) 1.0/sqrt(
-      distortion[BlackChannel]));
-  distortion[CompositeChannels]=20.0*MagickLog10((double) 1.0/sqrt(
-    distortion[CompositeChannels]));
+    if (fabs(distortion[BlackChannel]) >= MagickEpsilon)
+      distortion[BlackChannel]=20.0*MagickLog10((double) 1.0/sqrt(
+        distortion[BlackChannel]));
+  if (fabs(distortion[CompositeChannels]) >= MagickEpsilon)
+    distortion[CompositeChannels]=20.0*MagickLog10((double) 1.0/sqrt(
+      distortion[CompositeChannels]));
   return(status);
 }
 
@@ -1831,12 +1839,12 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   for (y=0; y < (ssize_t) rows; y++)
   {
     register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
+      *magick_restrict indexes,
+      *magick_restrict reconstruct_indexes;
 
     register const PixelPacket
-      *restrict p,
-      *restrict q;
+      *magick_restrict p,
+      *magick_restrict q;
 
     register ssize_t
       x;
@@ -2053,7 +2061,7 @@ MagickExport Image *SimilarityMetricImage(Image *image,const Image *reference,
       x;
 
     register PixelPacket
-      *restrict q;
+      *magick_restrict q;
 
     if (status == MagickFalse)
       continue;
