@@ -17,7 +17,7 @@
 %                              January 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -223,10 +223,13 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
             Parse width.
           */
           q=p;
-          if (LocaleNCompare(p,"0x",2) == 0)
-            *width=(size_t) strtol(p,&p,10);
-          else
-            *width=(size_t) floor(StringToDouble(p,&p)+0.5);
+          if (width != (size_t *) NULL)
+            {
+              if (LocaleNCompare(p,"0x",2) == 0)
+                *width=(size_t) strtol(p,&p,10);
+              else
+                *width=(size_t) floor(StringToDouble(p,&p)+0.5);
+            }
           if (p != q)
             flags|=WidthValue;
         }
@@ -243,7 +246,8 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
                 Parse height.
               */
               q=p;
-              *height=(size_t) floor(StringToDouble(p,&p)+0.5);
+              if (height != (size_t *) NULL)
+                *height=(size_t) floor(StringToDouble(p,&p)+0.5);
               if (p != q)
                 flags|=HeightValue;
             }
@@ -261,11 +265,12 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
         p++;
       }
       q=p;
-      *x=(ssize_t) ceil(StringToDouble(p,&p)-0.5);
+      if (x != (ssize_t *) NULL)
+        *x=(ssize_t) ceil(StringToDouble(p,&p)-0.5);
       if (p != q)
         {
           flags|=XValue;
-          if ((flags & XNegative) != 0)
+          if (((flags & XNegative) != 0) && (x != (ssize_t *) NULL))
             *x=(-*x);
         }
     }
@@ -281,11 +286,12 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
         p++;
       }
       q=p;
-      *y=(ssize_t) ceil(StringToDouble(p,&p)-0.5);
+      if (y != (ssize_t *) NULL)
+        *y=(ssize_t) ceil(StringToDouble(p,&p)-0.5);
       if (p != q)
         {
           flags|=YValue;
-          if ((flags & YNegative) != 0)
+          if (((flags & YNegative) != 0) && (y != (ssize_t *) NULL))
             *y=(-*y);
         }
     }
@@ -293,11 +299,13 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
     {
       if (((flags & SeparatorValue) == 0) && ((flags & HeightValue) == 0))
         {
-          *height=(*width);
+          if ((height != (size_t *) NULL) && (width != (size_t *) NULL))
+            *height=(*width);
           flags|=HeightValue;
         }
-      if (((flags & SeparatorValue) != 0) && ((flags & WidthValue) == 0))
-        *width=(*height);
+      if (((flags & SeparatorValue) != 0) && ((flags & WidthValue) == 0) &&
+          (height != (size_t *) NULL) && (width != (size_t *) NULL))
+            *width=(*height);
     }
 #if 0
   /*
@@ -342,118 +350,136 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
 */
 MagickExport char *GetPageGeometry(const char *page_geometry)
 {
-  static const char
-    *PageSizes[][2]=
+#define MagickPageSize(name,geometry) { (name), sizeof(name)-1, (geometry) }
+
+  typedef struct _PageInfo
+  {
+    const char
+      *name;
+
+    size_t
+      extent;
+
+    const char
+      *geometry;
+  } PageInfo;
+
+  static const PageInfo
+    PageSizes[] =
     {
-      { "4x6",  "288x432" },
-      { "5x7",  "360x504" },
-      { "7x9",  "504x648" },
-      { "8x10", "576x720" },
-      { "9x11",  "648x792" },
-      { "9x12",  "648x864" },
-      { "10x13",  "720x936" },
-      { "10x14",  "720x1008" },
-      { "11x17",  "792x1224" },
-      { "a0",  "2384x3370" },
-      { "a1",  "1684x2384" },
-      { "a10", "73x105" },
-      { "a2",  "1191x1684" },
-      { "a3",  "842x1191" },
-      { "a4",  "595x842" },
-      { "a4small", "595x842" },
-      { "a5",  "420x595" },
-      { "a6",  "297x420" },
-      { "a7",  "210x297" },
-      { "a8",  "148x210" },
-      { "a9",  "105x148" },
-      { "archa", "648x864" },
-      { "archb", "864x1296" },
-      { "archC", "1296x1728" },
-      { "archd", "1728x2592" },
-      { "arche", "2592x3456" },
-      { "b0",  "2920x4127" },
-      { "b1",  "2064x2920" },
-      { "b10", "91x127" },
-      { "b2",  "1460x2064" },
-      { "b3",  "1032x1460" },
-      { "b4",  "729x1032" },
-      { "b5",  "516x729" },
-      { "b6",  "363x516" },
-      { "b7",  "258x363" },
-      { "b8",  "181x258" },
-      { "b9",  "127x181" },
-      { "c0",  "2599x3676" },
-      { "c1",  "1837x2599" },
-      { "c2",  "1298x1837" },
-      { "c3",  "918x1296" },
-      { "c4",  "649x918" },
-      { "c5",  "459x649" },
-      { "c6",  "323x459" },
-      { "c7",  "230x323" },
-      { "executive", "540x720" },
-      { "flsa", "612x936" },
-      { "flse", "612x936" },
-      { "folio",  "612x936" },
-      { "halfletter", "396x612" },
-      { "isob0", "2835x4008" },
-      { "isob1", "2004x2835" },
-      { "isob10", "88x125" },
-      { "isob2", "1417x2004" },
-      { "isob3", "1001x1417" },
-      { "isob4", "709x1001" },
-      { "isob5", "499x709" },
-      { "isob6", "354x499" },
-      { "isob7", "249x354" },
-      { "isob8", "176x249" },
-      { "isob9", "125x176" },
-      { "jisb0", "1030x1456" },
-      { "jisb1", "728x1030" },
-      { "jisb2", "515x728" },
-      { "jisb3", "364x515" },
-      { "jisb4", "257x364" },
-      { "jisb5", "182x257" },
-      { "jisb6", "128x182" },
-      { "ledger",  "1224x792" },
-      { "legal",  "612x1008" },
-      { "letter", "612x792" },
-      { "lettersmall",  "612x792" },
-      { "quarto",  "610x780" },
-      { "statement",  "396x612" },
-      { "tabloid",  "792x1224" },
-      { (char *) NULL, (char *) NULL }
+      MagickPageSize("4x6", "288x432"),
+      MagickPageSize("5x7", "360x504"),
+      MagickPageSize("7x9", "504x648"),
+      MagickPageSize("8x10", "576x720"),
+      MagickPageSize("9x11", "648x792"),
+      MagickPageSize("9x12", "648x864"),
+      MagickPageSize("10x13", "720x936"),
+      MagickPageSize("10x14", "720x1008"),
+      MagickPageSize("11x17", "792x1224"),
+      MagickPageSize("a0", "2384x3370"),
+      MagickPageSize("a1", "1684x2384"),
+      MagickPageSize("a10", "73x105"),
+      MagickPageSize("a2", "1191x1684"),
+      MagickPageSize("a3", "842x1191"),
+      MagickPageSize("a4", "595x842"),
+      MagickPageSize("a4small", "595x842"),
+      MagickPageSize("a5", "420x595"),
+      MagickPageSize("a6", "297x420"),
+      MagickPageSize("a7", "210x297"),
+      MagickPageSize("a8", "148x210"),
+      MagickPageSize("a9", "105x148"),
+      MagickPageSize("archa", "648x864"),
+      MagickPageSize("archb", "864x1296"),
+      MagickPageSize("archC", "1296x1728"),
+      MagickPageSize("archd", "1728x2592"),
+      MagickPageSize("arche", "2592x3456"),
+      MagickPageSize("b0", "2920x4127"),
+      MagickPageSize("b1", "2064x2920"),
+      MagickPageSize("b10", "91x127"),
+      MagickPageSize("b2", "1460x2064"),
+      MagickPageSize("b3", "1032x1460"),
+      MagickPageSize("b4", "729x1032"),
+      MagickPageSize("b5", "516x729"),
+      MagickPageSize("b6", "363x516"),
+      MagickPageSize("b7", "258x363"),
+      MagickPageSize("b8", "181x258"),
+      MagickPageSize("b9", "127x181"),
+      MagickPageSize("c0", "2599x3676"),
+      MagickPageSize("c1", "1837x2599"),
+      MagickPageSize("c2", "1298x1837"),
+      MagickPageSize("c3", "918x1296"),
+      MagickPageSize("c4", "649x918"),
+      MagickPageSize("c5", "459x649"),
+      MagickPageSize("c6", "323x459"),
+      MagickPageSize("c7", "230x323"),
+      MagickPageSize("executive", "540x720"),
+      MagickPageSize("flsa", "612x936"),
+      MagickPageSize("flse", "612x936"),
+      MagickPageSize("folio", "612x936"),
+      MagickPageSize("halfletter", "396x612"),
+      MagickPageSize("isob0", "2835x4008"),
+      MagickPageSize("isob1", "2004x2835"),
+      MagickPageSize("isob10", "88x125"),
+      MagickPageSize("isob2", "1417x2004"),
+      MagickPageSize("isob3", "1001x1417"),
+      MagickPageSize("isob4", "709x1001"),
+      MagickPageSize("isob5", "499x709"),
+      MagickPageSize("isob6", "354x499"),
+      MagickPageSize("isob7", "249x354"),
+      MagickPageSize("isob8", "176x249"),
+      MagickPageSize("isob9", "125x176"),
+      MagickPageSize("jisb0", "1030x1456"),
+      MagickPageSize("jisb1", "728x1030"),
+      MagickPageSize("jisb2", "515x728"),
+      MagickPageSize("jisb3", "364x515"),
+      MagickPageSize("jisb4", "257x364"),
+      MagickPageSize("jisb5", "182x257"),
+      MagickPageSize("jisb6", "128x182"),
+      MagickPageSize("ledger", "1224x792"),
+      MagickPageSize("legal", "612x1008"),
+      MagickPageSize("letter", "612x792"),
+      MagickPageSize("lettersmall", "612x792"),
+      MagickPageSize("quarto", "610x780"),
+      MagickPageSize("statement", "396x612"),
+      MagickPageSize("tabloid", "792x1224")
     };
 
   char
-    *page;
+    page[MaxTextExtent];
 
   register ssize_t
     i;
 
   assert(page_geometry != (char *) NULL);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",page_geometry);
-  page=AcquireString(page_geometry);
-  for (i=0; *PageSizes[i] != (char *) NULL; i++)
-    if (LocaleNCompare(PageSizes[i][0],page,strlen(PageSizes[i][0])) == 0)
+  CopyMagickString(page,page_geometry,MaxTextExtent);
+  for (i=0; i < (ssize_t) (sizeof(PageSizes)/sizeof(PageSizes[0])); i++)
+  {
+    int
+      status;
+    
+    status=LocaleNCompare(PageSizes[i].name,page_geometry,PageSizes[i].extent);
+    if (status == 0)
       {
-        RectangleInfo
-          geometry;
-
         MagickStatusType
           flags;
 
+        RectangleInfo
+          geometry;
+
         /*
           Replace mneumonic with the equivalent size in dots-per-inch.
         */
-        (void) CopyMagickString(page,PageSizes[i][1],MaxTextExtent);
-        (void) ConcatenateMagickString(page,page_geometry+
-          strlen(PageSizes[i][0]),MaxTextExtent);
+        (void) FormatLocaleString(page,MaxTextExtent,"%s%.80s",
+          PageSizes[i].geometry,page_geometry+PageSizes[i].extent);
         flags=GetGeometry(page,&geometry.x,&geometry.y,&geometry.width,
           &geometry.height);
         if ((flags & GreaterValue) == 0)
           (void) ConcatenateMagickString(page,">",MaxTextExtent);
         break;
       }
-  return(page);
+  }
+  return(AcquireString(page));
 }
 
 /*
@@ -725,9 +751,9 @@ MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
   p=(char *) geometry;
   for (i=0; (*p != '\0') && (i < 6); i++)
   {
-    GetMagickToken(p,&p,token);
+    GetNextToken(p,&p,MaxTextExtent,token);
     if (*token == ',')
-      GetMagickToken(p,&p,token);
+      GetNextToken(p,&p,MaxTextExtent,token);
     switch (i)
     {
       case 0:
@@ -840,12 +866,12 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   (void) CopyMagickString(pedantic_geometry,geometry,MaxTextExtent);
   for (p=pedantic_geometry; *p != '\0'; )
   {
-    if (isspace((int) ((unsigned char) *p)) != 0)
+    c=(int) ((unsigned char) *p);
+    if (isspace(c) != 0)
       {
         (void) CopyMagickString(p,p+1,MaxTextExtent);
         continue;
       }
-    c=(int) ((unsigned char) *p);
     switch (c)
     {
       case '%':
@@ -926,7 +952,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         break;
       }
       default:
-        return(flags);
+        return(NoValue);
     }
   }
   /*
@@ -938,7 +964,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   q=p;
   value=StringToDouble(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
-    value=(double) strtol(p,&q,10);
+    (void) strtol(p,&q,10);
   c=(int) ((unsigned char) *q);
   if ((c == 215) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
       (*q == '/') || (*q == ':') || (*q =='\0'))
@@ -991,17 +1017,17 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       if ((*p == ',') || (*p == '/') || (*p == ':') )
         p++;
       while ((*p == '+') || (*p == '-'))
-        {
-          if (*p == '-')
-            flags^=XiNegative;  /* negate sign */
-          p++;
-        }
+      {
+        if (*p == '-')
+          flags^=XiNegative;  /* negate sign */
+        p++;
+      }
       q=p;
       value=StringToDouble(p,&p);
       if (p != q)
         {
           flags|=XiValue;
-          if ((flags&XiNegative) != 0)
+          if ((flags & XiNegative) != 0)
             value=(-value);
           geometry_info->xi=value;
         }
@@ -1026,7 +1052,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
           if (p != q)
             {
               flags|=PsiValue;
-              if ((flags&PsiNegative) != 0)
+              if ((flags & PsiNegative) != 0)
                 value=(-value);
               geometry_info->psi=value;
             }
@@ -1052,7 +1078,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
           if (p != q)
             {
               flags|=ChiValue;
-              if ((flags&ChiNegative) != 0)
+              if ((flags & ChiNegative) != 0)
                 value=(-value);
               geometry_info->chi=value;
             }
@@ -1375,8 +1401,8 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       (void) ParseGeometry(geometry,&geometry_info);
       area=geometry_info.rho+sqrt(MagickEpsilon);
       distance=sqrt((double) former_width*former_height);
-      scale.x=former_width/(distance/sqrt(area));
-      scale.y=former_height/(distance/sqrt(area));
+      scale.x=(double) former_width/(distance/sqrt(area));
+      scale.y=(double) former_height/(distance/sqrt(area));
       if ((scale.x < (double) *width) || (scale.y < (double) *height))
         {
           *width=(unsigned long) (former_width/(distance/sqrt(area)));
