@@ -17,7 +17,7 @@
 %                               August 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the license.  You may  %
@@ -923,14 +923,17 @@ MagickExport char *EscapeString(const char *source,const char escape)
     length;
 
   assert(source != (const char *) NULL);
-  length=strlen(source);
+  length=0;
   for (p=source; *p != '\0'; p++)
+  {
     if ((*p == '\\') || (*p == escape))
       {
         if (~length < 1)
           ThrowFatalException(ResourceLimitFatalError,"UnableToEscapeString");
         length++;
       }
+    length++;
+  }
   destination=(char *) NULL;
   if (~length >= (MaxTextExtent-1))
     destination=(char *) AcquireQuantumMemory(length+MaxTextExtent,
@@ -1345,8 +1348,8 @@ MagickExport const char *GetStringInfoPath(const StringInfo *string_info)
 %      after the last character used in the conversion.
 %
 */
-MagickExport double InterpretSiPrefixValue(const char *restrict string,
-  char **restrict sentinal)
+MagickExport double InterpretSiPrefixValue(const char *magick_restrict string,
+  char **magick_restrict sentinal)
 {
   char
     *q;
@@ -1496,204 +1499,6 @@ MagickExport MagickBooleanType IsStringNotFalse(const char *value)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   L o c a l e C o m p a r e                                                 %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  LocaleCompare() performs a case-insensitive comparison of two strings
-%  byte-by-byte, according to the ordering of the current locale encoding.
-%  LocaleCompare returns an integer greater than, equal to, or less than 0,
-%  if the string pointed to by p is greater than, equal to, or less than the
-%  string pointed to by q respectively.  The sign of a non-zero return value
-%  is determined by the sign of the difference between the values of the first
-%  pair of bytes that differ in the strings being compared.
-%
-%  The format of the LocaleCompare method is:
-%
-%      int LocaleCompare(const char *p,const char *q)
-%
-%  A description of each parameter follows:
-%
-%    o p: A pointer to a character string.
-%
-%    o q: A pointer to a character string to compare to p.
-%
-*/
-MagickExport int LocaleCompare(const char *p,const char *q)
-{
-  if ((p == (char *) NULL) && (q == (char *) NULL))
-    return(0);
-  if (p == (char *) NULL)
-    return(-1);
-  if (q == (char *) NULL)
-    return(1);
-#if defined(MAGICKCORE_HAVE_STRCASECMP)
-  return(strcasecmp(p,q));
-#else
-  {
-    register int
-      c,
-      d;
-
-    for ( ; ; )
-    {
-      c=(int) *((unsigned char *) p);
-      d=(int) *((unsigned char *) q);
-      if ((c == 0) || (AsciiMap[c] != AsciiMap[d]))
-        break;
-      p++;
-      q++;
-    }
-    return(AsciiMap[c]-(int) AsciiMap[d]);
-  }
-#endif
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   L o c a l e L o w e r                                                     %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  LocaleLower() transforms all of the characters in the supplied
-%  null-terminated string, changing all uppercase letters to lowercase.
-%
-%  The format of the LocaleLower method is:
-%
-%      void LocaleLower(char *string)
-%
-%  A description of each parameter follows:
-%
-%    o string: A pointer to the string to convert to lower-case Locale.
-%
-*/
-MagickExport void LocaleLower(char *string)
-{
-  register char
-    *q;
-
-  assert(string != (char *) NULL);
-  for (q=string; *q != '\0'; q++)
-    *q=(char) tolower((int) *q);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   L o c a l e N C o m p a r e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  LocaleNCompare() performs a case-insensitive comparison of two strings
-%  byte-by-byte, according to the ordering of the current locale encoding.
-%
-%  LocaleNCompare returns an integer greater than, equal to, or less than 0,
-%  if the string pointed to by p is greater than, equal to, or less than the
-%  string pointed to by q respectively.  The sign of a non-zero return value
-%  is determined by the sign of the difference between the values of the first
-%  pair of bytes that differ in the strings being compared.
-%
-%  The LocaleNCompare method makes the same comparison as LocaleCompare but
-%  looks at a maximum of n bytes.  Bytes following a null byte are not
-%  compared.
-%
-%  The format of the LocaleNCompare method is:
-%
-%      int LocaleNCompare(const char *p,const char *q,const size_t n)
-%
-%  A description of each parameter follows:
-%
-%    o p: A pointer to a character string.
-%
-%    o q: A pointer to a character string to compare to p.
-%
-%    o length: the number of characters to compare in strings p and q.
-%
-*/
-MagickExport int LocaleNCompare(const char *p,const char *q,const size_t length)
-{
-  if ((p == (char *) NULL) && (q == (char *) NULL))
-    return(0);
-  if (p == (char *) NULL)
-    return(-1);
-  if (q == (char *) NULL)
-    return(1);
-#if defined(MAGICKCORE_HAVE_STRNCASECMP)
-  return(strncasecmp(p,q,length));
-#else
-  {
-    register int
-      c,
-      d;
-
-    register size_t
-      i;
-
-    for (i=length; i != 0; i--)
-    {
-      c=(int) *((unsigned char *) p);
-      d=(int) *((unsigned char *) q);
-      if (AsciiMap[c] != AsciiMap[d])
-        return(AsciiMap[c]-(int) AsciiMap[d]);
-      if (c == 0)
-        return(0);
-      p++;
-      q++;
-    }
-    return(0);
-  }
-#endif
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   L o c a l e U p p e r                                                     %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  LocaleUpper() transforms all of the characters in the supplied
-%  null-terminated string, changing all lowercase letters to uppercase.
-%
-%  The format of the LocaleUpper method is:
-%
-%      void LocaleUpper(char *string)
-%
-%  A description of each parameter follows:
-%
-%    o string: A pointer to the string to convert to upper-case Locale.
-%
-*/
-MagickExport void LocaleUpper(char *string)
-{
-  register char
-    *q;
-
-  assert(string != (char *) NULL);
-  for (q=string; *q != '\0'; q++)
-    *q=(char) toupper((int) *q);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   P r i n t S t r i n g I n f o                                             %
 %                                                                             %
 %                                                                             %
@@ -1812,6 +1617,55 @@ MagickExport void ResetStringInfo(StringInfo *string_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S a n t i z e S t r i n g                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SanitizeString() returns an new string removes all characters except
+%  letters, digits and !#$%&'*+-=?^_`{|}~@.[].
+%
+%  The returned string shoud be freed using DestoryString().
+%
+%  The format of the SanitizeString method is:
+%
+%      char *SanitizeString(const char *source)
+%
+%  A description of each parameter follows:
+%
+%    o source: A character string.
+%
+*/
+MagickExport char *SanitizeString(const char *source)
+{
+  char
+    *sanitize_source;
+
+  const char
+    *q;
+  
+  register char
+    *p;
+  
+  static char
+    whitelist[] =
+      "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789 "
+      "$-_.+!*'(),{}|\\^~[]`\"><#%;/?:@&=";
+  
+  sanitize_source=AcquireString(source);
+  p=sanitize_source;
+  q=sanitize_source+strlen(sanitize_source);
+  for (p+=strspn(p,whitelist); p != q; p+=strspn(p,whitelist))
+    *p='_';
+  return(sanitize_source);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S e t S t r i n g I n f o                                                 %
 %                                                                             %
 %                                                                             %
